## What's Changed

**新增：**
- 对部分需要 Webhook 的适配器（QQ 官方机器人、Slack、企业微信、微信客服、企业微信智能机器人、微信公众号）支持统一的 Webhook 链接模式，避免开多个端口。并支持在 WebUI 机器人卡片中查看和复制 Webhook 链接。详情请看：[统一 Webhook 模式](https://docs.astrbot.app/use/unified-webhook.html)
- 新增 Kubernetes 部署文档。

**修复：**
- 修复：Telegram 和 QQ 场景下，使用 Whisper API 报错。
- 修复：部分情况下 Slack 输出消息段代码的问题。
- 修复：当启动了流式输出时，QQ 官方机器人适配器无法正常回复消息。
- 修复：对话数据页的对话详情在暗夜模式下显示异常的问题。

**优化：**
- 重构：WebChat 的消息数据结构，支持引用回复、文件发送、时间显示等功能，优化思考内容显示的部分 Bug。
- 优化：机器人页面支持显示报错信息，方便排查问题。
